@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = ManualRanking
 
@@ -58,7 +56,7 @@ class MetasploitModule < Msf::Exploit::Remote
       [
         Opt::RPORT(8080),
         OptString.new('TARGETURI', [true, 'Path to SiteScope', '/SiteScope/'])
-      ], self.class)
+      ])
   end
 
   def uri
@@ -166,5 +164,4 @@ class MetasploitModule < Msf::Exploit::Remote
 
     return res
   end
-
 end
