@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-require 'msf/core'
 require 'msf/core/exploit/mssql_commands'
 
 class MetasploitModule < Msf::Exploit::Remote
@@ -27,7 +25,7 @@ class MetasploitModule < Msf::Exploit::Remote
         up a exploit/multi/handler to run in the background as a job to support multiple incoming
         shells.
 
-          If you are interested in deploying payloads to spefic servers this module also
+          If you are interested in deploying payloads to specific servers this module also
         supports that functionality via the "DEPLOYLIST" option.
 
           Currently, the module is capable of delivering payloads to both 32bit and 64bit
@@ -42,7 +40,7 @@ class MetasploitModule < Msf::Exploit::Remote
           'Scott Sutherland "nullbind" <scott.sutherland[at]netspi.com>'
         ],
       'Platform'      => [ 'win' ],
-      'Arch'           => [ ARCH_X86, ARCH_X86_64 ],
+      'Arch'           => [ ARCH_X86, ARCH_X64 ],
       'License'        => MSF_LICENSE,
       'References'     =>
         [
@@ -64,12 +62,12 @@ class MetasploitModule < Msf::Exploit::Remote
         OptBool.new('DEPLOY',       [false, 'Deploy payload via the sysadmin links', false]),
         OptString.new('DEPLOYLIST', [false,'Comma seperated list of systems to deploy to']),
         OptString.new('PASSWORD',   [true, 'The password for the specified username'])
-      ], self.class)
+      ])
 
     register_advanced_options(
       [
         OptString.new('POWERSHELL_PATH', [true, 'Path to powershell.exe', "C:\\windows\\syswow64\\WindowsPowerShell\\v1.0\\powershell.exe"])
-      ], self.class)
+      ])
   end
 
   def exploit
@@ -260,7 +258,7 @@ class MetasploitModule < Msf::Exploit::Remote
     if (save_loot=="yes")
       filename= "#{datastore['RHOST']}-#{datastore['RPORT']}_linked_servers.csv"
       path = store_loot("crawled_links", "text/plain", datastore['RHOST'], linked_server_table.to_csv, filename, "Linked servers",this_service)
-      print_status("Results have been saved to: #{path}")
+      print_good("Results have been saved to: #{path}")
     end
   end
 
